//--------------------------------------------------------------------
//	
//	TToolTipControls.h
//
//  Written by Robert Polic
//
//--------------------------------------------------------------------

#ifndef T_TOOL_TIP_CONTROLS_H
#define T_TOOL_TIP_CONTROLS_H

#include <Button.h>
#include <ColorControl.h>
#include <CheckBox.h>
#include <PictureButton.h>
#include <RadioButton.h>
#include <Slider.h>
#include <TextControl.h>


//====================================================================
//
// BButton sub-class that adds a ToolTip
//
//====================================================================

class TToolTipButton : public BButton
{
public:
						TToolTipButton(BRect frame,
									   const char *name,
									   const char *label,
									   BMessage *message,
									   const char *tip,
									   uint32 resizeMask = B_FOLLOW_LEFT |
														   B_FOLLOW_TOP, 
									   uint32 flags = B_WILL_DRAW |
													  B_NAVIGABLE); 
						~TToolTipButton();
	virtual void		MouseMoved(BPoint where,
								   uint32 code,
								   const BMessage*);

private:
	bool				fIn;
	char				*fTip;
};


//====================================================================
//
// BCheckBox sub-class that adds a ToolTip
//
//====================================================================

class TToolTipCheckBox : public BCheckBox
{
public:
						TToolTipCheckBox(BRect frame,
										 const char *name,
										 const char *label,
										 BMessage *message,
										 const char *tip,
										 uint32 resizeMask = B_FOLLOW_LEFT |
															 B_FOLLOW_TOP, 
										 uint32 flags = B_WILL_DRAW |
														B_NAVIGABLE); 
						~TToolTipCheckBox();
	virtual void		MouseMoved(BPoint where,
								   uint32 code,
								   const BMessage*);

private:
	bool				fIn;
	char				*fTip;
};


//====================================================================
//
// BColorControl sub-class that adds a ToolTip
//
//====================================================================

class TToolTipColorControl : public BColorControl
{
public:
						TToolTipColorControl(BPoint start,
											 color_control_layout layout,
											 float cell_size,
											 const char *name,
											 const char *tip,
											 BMessage *message = NULL,
											 bool use_offscreen = false);
						~TToolTipColorControl();
	virtual void		MouseMoved(BPoint where,
								   uint32 code,
								   const BMessage*);

private:
	bool				fIn;
	char				*fTip;
};


//====================================================================
//
// BRadioButton sub-class that adds a ToolTip
//
//====================================================================

class TToolTipRadioButton : public BRadioButton
{
public:
						TToolTipRadioButton(BRect frame,
											const char *name,
											const char *label,
											BMessage *message,
											const char *tip,
											uint32 resizeMask = B_FOLLOW_LEFT |
																B_FOLLOW_TOP, 
											uint32 flags = B_WILL_DRAW |
														   B_NAVIGABLE); 
						~TToolTipRadioButton();
	virtual void		MouseMoved(BPoint where,
								   uint32 code,
								   const BMessage*);

private:
	bool				fIn;
	char				*fTip;
};


//====================================================================
//
// BPictureButtonButton sub-class that adds a ToolTip
//
//====================================================================

class TToolTipPictureButton : public BPictureButton
{
public:
						TToolTipPictureButton(BRect frame,
											  const char *name,
											  BPicture *off,
											  BPicture *on,
											  BMessage *message,
											  const char *tip,
											  uint32 behavior = B_ONE_STATE_BUTTON,
											  uint32 resizeMask = B_FOLLOW_LEFT |
																  B_FOLLOW_TOP, 
											  uint32 flags = B_WILL_DRAW |
											  				 B_NAVIGABLE); 
						~TToolTipPictureButton();
	virtual void		MouseMoved(BPoint where,
								   uint32 code,
								   const BMessage*);

private:
	bool				fIn;
	char				*fTip;
};


//====================================================================
//
// BSlider sub-class that adds a ToolTip
//
//====================================================================

class TToolTipSlider : public BSlider
{
public:
						TToolTipSlider(BRect frame,
									   const char *name,
									   const char *label,
									   BMessage *message,
									   int32 minValue,
									   int32 maxValue,
									   const char *tip,
									   thumb_style thumbType = B_BLOCK_THUMB,
									   uint32 resizeMask = B_FOLLOW_LEFT |
														   B_FOLLOW_TOP,
									   uint32 flags = B_NAVIGABLE |
													  B_WILL_DRAW |
													  B_FRAME_EVENTS);
						~TToolTipSlider();
	virtual void		MouseMoved(BPoint where,
								   uint32 code,
								   const BMessage*);

private:
	bool				fIn;
	char				*fTip;
};


//====================================================================
//
// BTextControl sub-class that adds a ToolTip
//
//====================================================================

class TToolTipTextControl : public BTextControl
{
public:
						TToolTipTextControl(BRect frame,
											const char *name,
											const char *label,
											const char *initial_text,
											BMessage *message,
											const char *tip,
											uint32 resizeMask = B_FOLLOW_LEFT |
																B_FOLLOW_TOP,
											uint32 flags = B_WILL_DRAW |
														   B_NAVIGABLE);
						~TToolTipTextControl();
	virtual void		KeyDown(const char *bytes,
								int32 numBytes);
	virtual void		MouseMoved(BPoint where,
								   uint32 code,
								   const BMessage*);

private:
	bool				fIn;
};
#endif